# container-scanning

Container Scanning utility for SBU projects.

## Building

There are dedicated build stages in the pipeline to build and publish the new container image.

Building and publishing follow this process:
1. On push, re-build the container with the `CI_COMMIT_SHA` tag (i.e. non-`latest`)
2. Publish the container that is just built to `REGISTRY`
3. If pushed to the `master` branch, re-tag the image from the previous steps as `latest`

In case you want to re-build the container without actually pushing to the repo
(for example, to download the latest `cbctl` and `twistcli` binaries), just run
a pipeline (through the web interface works fine) and specify `BUILD` = `true`

## Running Scan Locally

**Prerequisites**:
- Running Docker daemon
- Access to needed credentials

In order to execute the scan locally, you can start from the provided example
scripts. Make sure you provide missing environment variables.  Provide the
image(s) you want to scan in `SCAN_IMAGE_LIST` as a space-separated list. Once
the scan is complete, you will have the `final_report.html` in the
`OUTPUT_DIR`.

**Note**: `BASE_IMAGES` is used to find if scanned image is based on any of the
approved latest RE images (as it should be). You can provide an empty list
in order to speed up the scan and not download all of those.

### Scan with cbctl

```sh
CB_API_ID=
CB_API_KEY=
ORG_KEY=
DEFAULT_BUILD_STEPS=	# e.g. production
SAAS_BASE_URL=		# host e.g. defense.conferdeploy.net

SAAS_URL=https://${SAAS_BASE_URL}/containers
IMAGE=artifactory-pub.bit9.local:5000/prodsec-csi/psec-container-scanner
TAG=latest
REP_PATH_CLI=reports/cli
SCAN_IMAGE_LIST="artifactory-pub.bit9.local:5001/re/releng/photon3:latest harbor-repo.vmware.com/dockerhub-proxy-cache/library/alpine:latest"
BASE_IMAGES="artifactory-pub.bit9.local:5000/re/releng/photon3:latest artifactory-pub.bit9.local:5000/re/releng/photon3-python3:latest artifactory-pub.bit9.local:5000/re/releng/photon3-go:latest artifactory-pub.bit9.local:5000/re/releng/photon3-vmware-goboring-crypto:latest artifactory-pub.bit9.local:5000/re/releng/photon3-java:latest artifactory-pub.bit9.local:5000/re/releng/photon3-tomcat9-corretto8:latest artifactory-pub.bit9.local:5000/re/releng/photon3-tomcat10-corretto8:latest artifactory-pub.bit9.local:5000/re/releng/photon3-nginx:latest artifactory-pub.bit9.local:5000/re/releng/photon4:latest artifactory-pub.bit9.local:5000/re/releng/photon4-nginx:latest"
OUTPUT_DIR=$(pwd)/output

mkdir "${OUTPUT_DIR}" 2>/dev/null

docker run \
        --rm \
        -it \
        -e CB_API_ID="${CB_API_ID}" \
        -e CB_API_KEY="${CB_API_KEY}" \
        -e DEFAULT_BUILD_STEPS="${DEFAULT_BUILD_STEPS}" \
        -e ORG_KEY="${ORG_KEY}" \
        -e SAAS_URL="${SAAS_URL}" \
        -e SAAS_BASE_URL="${SAAS_BASE_URL}" \
        -e BASE_IMAGES="${BASE_IMAGES}" \
        -e REP_PATH_CLI="${REP_PATH_CLI}" \
        -v "${OUTPUT_DIR}:/root/${REP_PATH_CLI}" \
        -v /var/run/docker.sock:/var/run/docker.sock \
        ${IMAGE}:${TAG} -c -s "${SCAN_IMAGE_LIST}"
```

### Scan with twistcli

```sh
TWIST_CLI_H=	# host e.g. twistlock-corp-psco01-stg-gov-psco01-us-gov-west-1.vdp-int-stg.vmware.com
TWIST_CLI_U=	# user
TWIST_CLI_P=	# password

IMAGE=artifactory-pub.bit9.local:5000/prodsec-csi/psec-container-scanner
TAG=latest
REP_PATH_CLI=reports/cli
SCAN_IMAGE_LIST="artifactory-pub.bit9.local:5001/re/releng/photon3:latest harbor-repo.vmware.com/dockerhub-proxy-cache/library/alpine:latest"
BASE_IMAGES="artifactory-pub.bit9.local:5000/re/releng/photon3:latest artifactory-pub.bit9.local:5000/re/releng/photon3-python3:latest artifactory-pub.bit9.local:5000/re/releng/photon3-go:latest artifactory-pub.bit9.local:5000/re/releng/photon3-vmware-goboring-crypto:latest artifactory-pub.bit9.local:5000/re/releng/photon3-java:latest artifactory-pub.bit9.local:5000/re/releng/photon3-tomcat9-corretto8:latest artifactory-pub.bit9.local:5000/re/releng/photon3-tomcat10-corretto8:latest artifactory-pub.bit9.local:5000/re/releng/photon3-nginx:latest artifactory-pub.bit9.local:5000/re/releng/photon4:latest artifactory-pub.bit9.local:5000/re/releng/photon4-nginx:latest"
OUTPUT_DIR=$(pwd)/output

mkdir "${OUTPUT_DIR}" 2>/dev/null

docker run \
        --rm \
        -it \
        -e BASE_IMAGES="${BASE_IMAGES}" \
        -e REP_PATH_CLI="${REP_PATH_CLI}" \
        -e TWIST_CLI_H="${TWIST_CLI_H}" \
        -e TWIST_CLI_U="${TWIST_CLI_U}" \
        -e TWIST_CLI_P="${TWIST_CLI_P}" \
        -v "${OUTPUT_DIR}:/root/${REP_PATH_CLI}" \
        -v /var/run/docker.sock:/var/run/docker.sock \
        ${IMAGE}:${TAG} -t -s "${SCAN_IMAGE_LIST}"
```
